@@ -5,8 +5,8 @@
 #' @description Create an `R6` object to submit tasks and
 #'   launch workers on a PBS or TORQUE cluster.
 #' @inheritSection crew.cluster-package Attribution
-#' @inheritParams crew::crew_client
 #' @inheritParams crew_launcher_pbs
+#' @inheritParams crew::crew_client
 #' @inheritParams crew::crew_controller
 #' @param seconds_exit Deprecated on 2023-09-21 in version 0.1.2.9000.
 #'   No longer necessary.
@@ -27,6 +27,7 @@ crew_controller_pbs <- function(
   tls = crew::crew_tls(mode = "automatic"),
   tls_enable = NULL,
   tls_config = NULL,
+  serialization = NULL,
   seconds_interval = 0.25,
   seconds_timeout = 60,
   seconds_launch = 86400,
@@ -82,6 +83,7 @@ crew_controller_pbs <- function(
     tls = tls,
     tls_enable = tls_enable,
     tls_config = tls_config,
+    serialization = serialization,
     seconds_interval = seconds_interval,
     seconds_timeout = seconds_timeout
   )
