@@ -4,8 +4,10 @@ test_that("SGE minimal", {
     workers = 1L,
     seconds_launch = 604800,
     seconds_idle = 300,
-    script_lines = paste0("module load R/", getRversion()),
-    verbose = TRUE
+    options_cluster = crew_options_sge(
+      script_lines = paste0("module load R/", getRversion()),
+      verbose = TRUE
+    )
   )
   on.exit(controller$terminate())
   controller$start()
