@@ -1,5 +1,19 @@
 test_that("crew_controller_slurm() script() nearly empty", {
-  x <- crew_controller_slurm(slurm_time_minutes = NULL)
+  x <- crew_controller_slurm()
+  lines <- c(
+    "#!/bin/sh",
+    "#SBATCH --job-name=name",
+    "#SBATCH --output=/dev/null",
+    "#SBATCH --error=/dev/null",
+    "#SBATCH --ntasks=1"
+  )
+  expect_equal(x$launcher$script(name = "name"), lines)
+})
+
+test_that("crew_controller_slurm() script() without --ntasks", {
+  x <- crew_controller_slurm(
+    options_cluster = crew_options_slurm(n_tasks = NULL)
+  )
   lines <- c(
     "#!/bin/sh",
     "#SBATCH --job-name=name",
@@ -18,7 +32,8 @@ test_that("crew_controller_slurm() script() all lines", {
       memory_gigabytes_required = 5.07,
       memory_gigabytes_per_cpu = 4.07,
       cpus_per_task = 2,
-      time_minutes = 57
+      time_minutes = 57,
+      n_tasks = 3
     )
   )
   out <- x$launcher$script(name = "my_name")
@@ -31,6 +46,7 @@ test_that("crew_controller_slurm() script() all lines", {
     "#SBATCH --mem-per-cpu=4168M",
     "#SBATCH --cpus-per-task=2",
     "#SBATCH --time=57",
+    "#SBATCH --ntasks=3",
     "module load R",
     "echo 'start'"
   )
